
# This file was automatically generated by Dist::Zilla::Plugin::Alien v0.023.
use strict;
use warnings;

use Module::Build 0.28;
use lib qw{inc}; use Alien::Base::ModuleBuild;

my %module_build_args = (
  "alien_inline_auto_include" => [],
  "alien_name" => "GHTTP",
  "alien_repository" => {
    "host" => "",
    "location" => "inc",
    "pattern" => "^libghttp-(1\\.0\\.9)\\.patched\\.tar\\.gz\$",
    "protocol" => "local"
  },
  "configure_requires" => {
    "Alien::Base" => 0,
    "Alien::Base::ModuleBuild" => "0.002",
    "File::ShareDir" => "1.03"
  },
  "dist_abstract" => "(DEPRECATED) Easy installation of the GNOME libghttp library",
  "dist_author" => [
    "Chase Whitener <capoeirab\@cpan.org>"
  ],
  "dist_name" => "Alien-GHTTP",
  "dist_version" => "0.005",
  "license" => "perl",
  "module_name" => "Alien::GHTTP",
  "recursive_test_files" => 1,
  "requires" => {
    "Alien::Base" => "0.002",
    "File::ShareDir" => "1.03",
    "Module::Build" => "0.28",
    "perl" => "5.008001",
    "strict" => 0,
    "warnings" => 0
  },
  "test_requires" => {
    "ExtUtils::MakeMaker" => 0,
    "File::Spec" => 0,
    "IO::Handle" => 0,
    "IPC::Open3" => 0,
    "Test::More" => "0.88"
  }
);


my %fallback_build_requires = (
  "ExtUtils::MakeMaker" => 0,
  "File::Spec" => 0,
  "IO::Handle" => 0,
  "IPC::Open3" => 0,
  "Test::More" => "0.88"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Alien::Base::ModuleBuild->new(%module_build_args);


$build->create_build_script;
